==> qpid-proton-0.39.0_1.x86_64_linux.bottle.tar.gz: qpid-proton/0.39.0_1/lib/cmake/Proton/ProtonTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Proton::qpid-proton" for configuration "Release"
set_property(TARGET Proton::qpid-proton APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Proton::qpid-proton PROPERTIES
  IMPORTED_LOCATION_RELEASE "@@HOMEBREW_CELLAR@@/qpid-proton/0.39.0_1/lib/libqpid-proton.so.11.17.0"
  IMPORTED_SONAME_RELEASE "libqpid-proton.so.11"
  )

list(APPEND _cmake_import_check_targets Proton::qpid-proton )
list(APPEND _cmake_import_check_files_for_Proton::qpid-proton "@@HOMEBREW_CELLAR@@/qpid-proton/0.39.0_1/lib/libqpid-proton.so.11.17.0" )

# Import target "Proton::core" for configuration "Release"
set_property(TARGET Proton::core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Proton::core PROPERTIES
  IMPORTED_LOCATION_RELEASE "@@HOMEBREW_CELLAR@@/qpid-proton/0.39.0_1/lib/libqpid-proton-core.so.10.14.1"
  IMPORTED_SONAME_RELEASE "libqpid-proton-core.so.10"
  )

list(APPEND _cmake_import_check_targets Proton::core )
list(APPEND _cmake_import_check_files_for_Proton::core "@@HOMEBREW_CELLAR@@/qpid-proton/0.39.0_1/lib/libqpid-proton-core.so.10.14.1" )

# Import target "Proton::proactor" for configuration "Release"
set_property(TARGET Proton::proactor APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Proton::proactor PROPERTIES
  IMPORTED_LOCATION_RELEASE "@@HOMEBREW_CELLAR@@/qpid-proton/0.39.0_1/lib/libqpid-proton-proactor.so.1.10.0"
  IMPORTED_SONAME_RELEASE "libqpid-proton-proactor.so.1"
  )

list(APPEND _cmake_import_check_targets Proton::proactor )
list(APPEND _cmake_import_check_files_for_Proton::proactor "@@HOMEBREW_CELLAR@@/qpid-proton/0.39.0_1/lib/libqpid-proton-proactor.so.1.10.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> qpid-proton-0.40.0.x86_64_linux.bottle.tar.gz: qpid-proton/0.40.0/lib/cmake/Proton/ProtonTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Proton::qpid-proton" for configuration "Release"
set_property(TARGET Proton::qpid-proton APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Proton::qpid-proton PROPERTIES
  IMPORTED_LOCATION_RELEASE "@@HOMEBREW_CELLAR@@/qpid-proton/0.40.0/lib/libqpid-proton.so.11.18.0"
  IMPORTED_SONAME_RELEASE "libqpid-proton.so.11"
  )

list(APPEND _cmake_import_check_targets Proton::qpid-proton )
list(APPEND _cmake_import_check_files_for_Proton::qpid-proton "@@HOMEBREW_CELLAR@@/qpid-proton/0.40.0/lib/libqpid-proton.so.11.18.0" )

# Import target "Proton::core" for configuration "Release"
set_property(TARGET Proton::core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Proton::core PROPERTIES
  IMPORTED_LOCATION_RELEASE "@@HOMEBREW_CELLAR@@/qpid-proton/0.40.0/lib/libqpid-proton-core.so.10.15.0"
  IMPORTED_SONAME_RELEASE "libqpid-proton-core.so.10"
  )

list(APPEND _cmake_import_check_targets Proton::core )
list(APPEND _cmake_import_check_files_for_Proton::core "@@HOMEBREW_CELLAR@@/qpid-proton/0.40.0/lib/libqpid-proton-core.so.10.15.0" )

# Import target "Proton::proactor" for configuration "Release"
set_property(TARGET Proton::proactor APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Proton::proactor PROPERTIES
  IMPORTED_LOCATION_RELEASE "@@HOMEBREW_CELLAR@@/qpid-proton/0.40.0/lib/libqpid-proton-proactor.so.1.10.1"
  IMPORTED_SONAME_RELEASE "libqpid-proton-proactor.so.1"
  )

list(APPEND _cmake_import_check_targets Proton::proactor )
list(APPEND _cmake_import_check_files_for_Proton::proactor "@@HOMEBREW_CELLAR@@/qpid-proton/0.40.0/lib/libqpid-proton-proactor.so.1.10.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
